@@ -48,6 +48,8 @@ class CloudFormationLintRule(object):
     def __init__(self):
         self.resource_property_types = []
         self.resource_sub_property_types = []
+        self.config = {}  # `-X E3012:strict=false`... Show more
+        self.config_definition = {}
 
     def __repr__(self):
         return '%s: %s' % (self.id, self.shortdesc)
@@ -59,6 +61,24 @@ class CloudFormationLintRule(object):
     def initialize(self, cfn):
         """Initialize the rule"""
 
+    def configure(self, configs=None):
+        """ Set the configuration """
+
+        # set defaults
+        if isinstance(self.config_definition, dict):
+            for config_name, config_values in self.config_definition.items():
+                self.config[config_name] = config_values['default']
+
+        if isinstance(configs, dict):
+            for key, value in configs.items():
+                if key in self.config_definition:
+                    if self.config_definition[key]['type'] == 'boolean':
+                        self.config[key] = cfnlint.helpers.bool_compare(value, True)
+                    elif self.config_definition[key]['type'] == 'string':
+                        self.config[key] = str(value)
+                    elif self.config_definition[key]['type'] == 'integer':
+                        self.config[key] = int(value)
+
     match = None
     match_resource_properties = None
     match_resource_sub_properties = None
@@ -134,7 +154,7 @@ class CloudFormationLintRule(object):
 class RulesCollection(object):
     """Collection of rules"""
 
-    def __init__(self, ignore_rules=None, include_rules=None, include_experimental=False):
+    def __init__(self, ignore_rules=None, include_rules=None, configure_rules=None, include_experimental=False):
         self.rules = []
 
         # Whether "experimental" rules should be added
@@ -143,7 +163,7 @@ class RulesCollection(object):
         # Make Ignore Rules not required
         self.ignore_rules = ignore_rules or []
         self.include_rules = include_rules or []
-
+        self.configure_rules = configure_rules or []
         # by default include 'W' and 'E'
         # 'I' has to be included manually for backwards compabitility
         self.include_rules.extend(['W', 'E'])
@@ -152,6 +172,8 @@ class RulesCollection(object):
         """Register rules"""
         if self.is_rule_enabled(rule.id, rule.experimental):
             self.rules.append(rule)
+            if rule.id in self.configure_rules:
+                rule.configure(self.configure_rules[rule.id])
 
     def __iter__(self):
         return iter(self.rules)
@@ -164,6 +186,8 @@ class RulesCollection(object):
         for rule in more:
             if self.is_rule_enabled(rule.id, rule.experimental):
                 self.rules.append(rule)
+                if rule.id in self.configure_rules:
+                    rule.configure(self.configure_rules[rule.id])
 
     def __repr__(self):
         return '\n'.join([rule.verbose()
@@ -342,14 +366,17 @@ class RulesCollection(object):
 
         return matches
 
-    @classmethod
-    def create_from_directory(cls, rulesdir):
+    def create_from_directory(self, rulesdir):
         """Create rules from directory"""
-        result = cls([])
+        result = []
         if rulesdir != '':
-            result.rules = cfnlint.helpers.load_plugins(os.path.expanduser(rulesdir))
+            result = cfnlint.helpers.load_plugins(os.path.expanduser(rulesdir))
 
-        return result
+        for rule in result:
+            if rule.id in self.configure_rules:
+                rule.configure(self.configure_rules[rule.id])
+
+        self.extend(result)
 
 
 class RuleMatch(object):
@@ -429,6 +456,9 @@ class Template(object):  # pylint: disable=R0904
             'Rules'
         ]
         self.transform_globals = {}
+        self.transform_pre = {}
+        self.transform_pre['Ref'] = self.search_deep_keys('Ref')
+        self.transform_pre['Fn::Sub'] = self.search_deep_keys('Fn::Sub')
         self.conditions = cfnlint.conditions.Conditions(self)
 
     def __deepcopy__(self, memo):
@@ -565,6 +595,22 @@ class Template(object):  # pylint: disable=R0904
 
         return results
 
+    def get_directives(self):
+        """ Get Directives"""
+        results = {}
+        for _, resource_values in self.template.get('Resources', {}).items():
+            ignore_rule_ids = resource_values.get('Metadata', {}).get('cfn-lint', {}).get('config', {}).get('ignore_checks', [])
+            for ignore_rule_id in ignore_rule_ids:
+                if ignore_rule_id not in results:
+                    results[ignore_rule_id] = []
+                location = self._loc(resource_values)
+                results[ignore_rule_id].append({
+                    'start': location[0],
+                    'end': location[2]
+                })
+
+        return results
+
     def _get_sub_resource_properties(self, keys, properties, path):
         """Used for recursive handling of properties in the keys"""
         LOGGER.debug('Get Sub Resource Properties from %s', keys)
@@ -1310,11 +1356,20 @@ class Runner(object):
                 self.rules.run(
                     self.filename, self.cfn))
 
-        # uniq the list of incidents
+        # uniq the list of incidents and filter out exceptions from the template
+        directives = self.cfn.get_directives()
         return_matches = []
-        for _, match in enumerate(matches):
+        for match in matches:
             if not any(match == u for u in return_matches):
-                return_matches.append(match)
+                if match.rule.id not in directives:
+                    return_matches.append(match)
+                else:
+                    exception = False
+                    for directive in directives.get(match.rule.id):
+                        if directive.get('start') <= match.linenumber <= directive.get('end'):
+                            exception = True
+                    if not exception:
+                        return_matches.append(match)
         return return_matches
 
 
